@@ -63,6 +63,7 @@ mod message;
 mod object;
 mod permissions;
 mod request_table;
+mod runtime;
 mod source;
 mod subscription;
 mod supervisor;
@@ -79,7 +80,7 @@ pub mod _priv {
     pub use crate::{
         envelope::{AnyMessageBorrowed, AnyMessageOwned, EnvelopeBorrowed, EnvelopeOwned},
         init::do_start,
-        message::{AnyMessage, LocalTypeId, MessageVTable, MESSAGE_LIST},
+        message::{AnyMessage, MessageVTable, MESSAGE_LIST},
         permissions::{AtomicPermissions, Permissions},
     };
     pub use linkme;
