@@ -26,6 +26,7 @@ use crate::{
     messages,
     object::{Object, ObjectArc},
     routers::{Outcome, Router},
+    runtime::RuntimeManager,
     scope::{self, Scope, ScopeShared},
     subscription::SubscriptionManager,
     tracing::TraceId,
@@ -47,6 +48,7 @@ pub(crate) struct Supervisor<R: Router<C>, C, X> {
     control: CachePadded<RwLock<ControlBlock<C>>>,
     scope_shared: Arc<ScopeShared>,
     status_subscription: Arc<SubscriptionManager>,
+    rt_manager: RuntimeManager,
 }
 
 struct ControlBlock<C> {
@@ -85,6 +87,7 @@ where
         router: R,
         restart_policy: RestartPolicy,
         termination_policy: TerminationPolicy,
+        rt_manager: RuntimeManager,
     ) -> Self {
         let control = ControlBlock {
             config: None,
@@ -109,6 +112,7 @@ where
             scope_shared: Arc::new(ScopeShared::new(ctx.group())),
             status_subscription: Arc::new(status_subscription),
             context: ctx,
+            rt_manager,
         }
     }
 
@@ -307,12 +311,11 @@ where
 
         let sv = self.clone();
 
-        // TODO: protect against panics (for `fn(..) -> impl Future`).
-        let fut = self.exec.exec(ctx);
-
         // TODO: move to `harness.rs`.
         let fut = async move {
-            info!(%addr, "started");
+            let thread = std::thread::current();
+
+            info!(%addr, thread = %thread.name().unwrap_or("?"), "started");
 
             sv.objects
                 .get(&key)
@@ -321,7 +324,7 @@ where
                 .expect("a supervisor stores only actors")
                 .on_start();
 
-            let fut = AssertUnwindSafe(async { fut.await.unify() }).catch_unwind();
+            let fut = AssertUnwindSafe(async { sv.exec.exec(ctx).await.unify() }).catch_unwind();
             let new_status = match fut.await {
                 Ok(Ok(())) => ActorStatus::TERMINATED,
                 Ok(Err(err)) => ActorStatus::FAILED.with_details(ErrorChain(&*err)),
@@ -379,6 +382,8 @@ where
             key: key_str,
         });
 
+        let rt = self.rt_manager.get(&meta);
+
         let actor = Actor::new(
             meta.clone(),
             addr,
@@ -389,7 +394,8 @@ where
 
         let scope = Scope::new(scope::trace_id(), addr, meta, self.scope_shared.clone());
         let fut = MeasurePoll::new(fut.instrument(span));
-        tokio::spawn(scope.within(fut));
+
+        rt.spawn(scope.within(fut));
         let object = self.context.book().get_owned(addr).expect("just created");
         Some(object)
     }
